@@ -18,16 +18,15 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include "config.h"
-
-#ifdef POSIX
-#include <termios.h>
-#endif
-
 char *copyright = "Copyright 1995, Andreas Garzotto "
                   "Portions Copyright, 1995, The PAL Group";
+
+/* --------------------------------------------------------------------
+                         local includes
+   -------------------------------------------------------------------- */
 #include "pal.h"
 #include "palpriv.h"
+#include "config.h"
 
 
 /* --------------------------------------------------------------------
@@ -38,7 +37,6 @@ static int ttyfd;
 static int timeout_occured = 0;
 static int timeout_secs = TIMEOUT_NORMAL;
 
-
 /* --------------------------------------------------------------------
                            Alarm Handler
    -------------------------------------------------------------------- */
@@ -61,74 +59,16 @@ static void alarm_handler(int sig)
 
 void SetBaudRate(char *ttyname, unsigned long baud)
 {
-#ifdef POSIX
-    struct termios term;
-    char  *b = getenv("LXTOOLS_BAUD");
-   
-    if (b)
-      sscanf(b, "%ld", &baud);
-
-    if ( tcgetattr(ttyfd, &term) < 0 )
-    {
-	perror( "tcgetattr()" );
-	exit ( 1 );
-    }
-    /* Change to 8 bit and 38400 I/O. */
-
-    term.c_iflag = 0;
-    term.c_oflag = 0;
-    term.c_lflag = 0;
-    term.c_cflag = CREAD|CS8;
-    term.c_cc[VMIN]  = 1;
-    term.c_cc[VTIME] = 0;
-
-   switch ( baud )
-    {
-	case 38400:
-	    cfsetispeed( &term, B38400 );
-	    cfsetospeed( &term, B38400 );
-	    break;
-	case 19200:
-	    cfsetispeed( &term, B19200 );
-	    cfsetospeed( &term, B19200 );
-	    break;
-	case 9600:
-	    cfsetispeed( &term, B9600 );
-	    cfsetospeed( &term, B9600 );
-	    break; 
-	case 4800:
-	    cfsetispeed( &term, B4800 );
-	    cfsetospeed( &term, B4800 );
-	    break;
-	case 2400:
-	    cfsetispeed( &term, B2400 );
-	    cfsetospeed( &term, B2400 );
-	    break;
-	case 1200:
-	    cfsetispeed( &term, B1200 );
-	    cfsetospeed( &term, B1200 );
-	    break;
-        default: break;
-    }
-    if ( tcsetattr(ttyfd, TCSANOW, &term) < 0 )
-    {
-	perror( "tcsetattr()" );
-	exit ( 1 );
-    }
-
-#else  
- /* This is a quite innefficient and dirty hack to set up the
+/* This is a quite innefficient and dirty hack to set up the
  * serial port, but it is much more portable that using
  * stty or ioctl */
-   char command[80], *b = getenv("LXTOOLS_BAUD");
    
+   char command[80], *b = getenv("LXTOOLS_BAUD");
+
    if (b)
       sscanf(b, "%ld", &baud);
    sprintf(command, STTY_COMMAND, baud, ttyname);
-   close(ttyfd);
    system(command);
-   ttyfd = open(ttyname, O_RDWR);
-#endif
 }
 
 /* -------------------------------------------------------------------
@@ -560,12 +500,12 @@ int FilerRequest(FILERCOM *pFiler, int Request, WORD Size, BYTE *pData)
 
 FILERCOM *FilerConnect(int PortNumber, unsigned long BaudRate, FLCB *pCb)
 {
+
    int f;
    FILERCOM *pFiler;
    char ttyname[20], *ttyn = getenv("LXTOOLS_LINE");
 
-   static unsigned long BaudTable[] =
-   {
+   unsigned static long BaudTable[]= {
       0,115200L,57600L,38400L,19200L,9600L,4800L,2400L,1200L,INV_BAUDRATE
    };
    
@@ -627,7 +567,9 @@ FILERCOM *FilerConnect(int PortNumber, unsigned long BaudRate, FLCB *pCb)
          }
 
          pFiler->Baud = BaudTable[f];
+	 close(ttyfd);
          SetBaudRate(ttyname, pFiler->Baud);
+	 ttyfd = open(ttyname, O_RDWR);
 	 if (ttyfd < 0) return 0;
 
          /* try 2 attempts */
@@ -641,7 +583,9 @@ FILERCOM *FilerConnect(int PortNumber, unsigned long BaudRate, FLCB *pCb)
 
    else {
       pFiler->Baud=BaudRate;
+      close(ttyfd);
       SetBaudRate(ttyname, BaudRate);
+      ttyfd = open(ttyname, O_RDWR);
       if (ttyfd < 0) return 0;
    }
    timeout_secs = TIMEOUT_NORMAL;
